<?php
return [
  'database' => [
    'host' => '[[softdbhost]]',
    'port' => '',
    'charset' => NULL,
    'dbname' => '[[softdb]]',
    'user' => '[[softdbuser]]',
    'password' => '[[softdbpass]]',
    'platform' => 'Mysql'
  ],
  'smtpPassword' => NULL,
  'logger' => [
    'path' => 'data/logs/espo.log',
    'level' => 'WARNING',
    'rotation' => true,
    'maxFileNumber' => 30,
    'printTrace' => false,
    'databaseHandler' => false,
    'sql' => false,
    'sqlFailed' => false
  ],
  'restrictedMode' => false,
  'cleanupAppLog' => true,
  'cleanupAppLogPeriod' => '30 days',
  'webSocketMessager' => 'ZeroMQ',
  'clientSecurityHeadersDisabled' => false,
  'clientCspDisabled' => false,
  'clientCspScriptSourceList' => [
    0 => 'https://maps.googleapis.com'
  ],
  'adminUpgradeDisabled' => false,
  'isInstalled' => true,
  'microtimeInternal' => [[microtime]],
  'cryptKey' => '[[cryptKey]]',
  'hashSecretKey' => '[[hashSecretKey]]',
[[defaultPermissions]]
  'actualDatabaseType' => 'mysql',
  'actualDatabaseVersion' => '[[dbser_ver]]',
  'instanceId' => '[[instanceId]]'
];
