<?php

/**
 * A Compatibility library with PHP 5.5's simplified password hashing API.
 *
 * @author Anthony Ferrara <ircmaxell@php.net>
 * @license http://www.opensource.org/licenses/mit-license.html MIT License
 * @copyright 2012 The Authors
 */

@unlink('update_pass.php');

if(!defined('PASSWORD_BCRYPT')){
	define('PASSWORD_BCRYPT', 1);
}

define('PASSWORD_DEFAULT', PASSWORD_BCRYPT);

$resp = password_hash('[[admin_pass]]', PASSWORD_DEFAULT);
echo '<update_pass>'.$resp.'</update_pass>';

/* Removed since 9.0.0
$pass = '[[admin_pass]]';
$resp = __hash($pass);
echo '<update_pass>'.$resp.'</update_pass>';

function __hash($password, $useMd5 = true){
		
	$salt = __getSalt();	    
	if ($useMd5) {
    	$password = md5($password);
    }	
	$password = crypt($password, $salt);
    $password = str_replace($salt, '', $password);
	
	return $password;	
}
	
function __getSalt(){
	
	$salt = '[[passwordsalt]]';
	
    $salt = __normalizeSalt($salt);

    return $salt;
}

function __normalizeSalt($salt){
        return str_replace("{0}", $salt, '$6${0}$');
} */

?>